@@ -4,11 +4,12 @@ pub mod char_types;
 pub mod def;
 pub mod float_types;
 pub mod int_types;
-pub mod mem;
+pub mod math;
 pub mod platform;
 pub mod pointer;
 pub mod slice;
 #[cfg(feature = "deps")]
 pub mod deps {
+    pub use cty;
     pub use platforms;
 }
